'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _cfStyleContainer = require('cf-style-container');

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _cfComponentLoading = require('cf-component-loading');

var _cfComponentBox = require('cf-component-box');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const NoItems = (0, _cfStyleContainer.createComponent)(() => ({
  margin: '0.7em'
}), 'p');
NoItems.setDisplayName('NoItems');

const tableStyles = ({ theme, loading, fixedLayout }) => ({
  display: 'table',
  borderCollapse: 'collapse',
  width: '100%',
  backgroundColor: theme.colors.white,
  tableLayout: fixedLayout ? 'fixed' : 'auto',
  cursor: 'pointer',
  pointerEvents: loading ? 'none' : 'auto'
});

const StyledTable = (0, _cfStyleContainer.createComponent)(tableStyles, 'table');
StyledTable.setDisplayName('Table');

const NonTableWrapper = (0, _cfStyleContainer.createComponent)(({ theme, loading }) => ({
  width: '100%',
  backgroundColor: theme.colors.white,
  cursor: 'pointer',
  pointerEvents: loading ? 'none' : 'auto'
}));
NonTableWrapper.setDisplayName('NonTableWrapper');

class Table extends _react2.default.Component {
  constructor() {
    super();
    this.renderExtraContent = this.renderExtraContent.bind(this);
  }
  getChildContext() {
    const { bordered, loading, empty, errored, renderTableToDom } = this.props;
    return {
      bordered,
      loading,
      errored,
      empty,
      renderTableToDom
    };
  }

  renderExtraContent() {
    const {
      loading,
      errored,
      empty,
      searching,
      noItemsNode,
      noItemsMatchingSearchNode,
      errorNode,
      translations
    } = this.props;

    if (errored) {
      return _react2.default.createElement(
        NoItems,
        null,
        errorNode || translations.error
      );
    }

    if (loading) {
      if (empty) {
        return loading && _react2.default.createElement(
          _cfComponentBox.Box,
          { display: 'inline-flex', padding: '8px' },
          _react2.default.createElement(_cfComponentLoading.Loading, { size: '1.5x' }),
          ' ',
          _react2.default.createElement(
            _cfComponentBox.Box,
            { marginLeft: '16px' },
            translations.loading
          )
        );
      }
    }

    if (empty) {
      if (searching) {
        return _react2.default.createElement(
          NoItems,
          null,
          noItemsMatchingSearchNode || translations.noItemsMatchingSearchTerm
        );
      }
      return _react2.default.createElement(
        NoItems,
        null,
        noItemsNode || translations.noItems
      );
    }

    return null;
  }

  render() {
    const { children, loading, renderTableToDom, fixedLayout } = this.props;
    // export default ({ loading, myProp }) => {
    //   return loading ? <div>'hello'</div> : <div>'not loading'</div>;
    // };
    return _react2.default.createElement(
      'div',
      null,
      renderTableToDom ? _react2.default.createElement(
        StyledTable,
        { loading: loading, fixedLayout: fixedLayout },
        children
      ) : _react2.default.createElement(
        NonTableWrapper,
        { loading: loading },
        ' ',
        children,
        ' '
      ),
      this.renderExtraContent()
    );
  }
}

Table.displayName = 'Table';

Table.childContextTypes = {
  bordered: _propTypes2.default.bool,
  loading: _propTypes2.default.bool,
  errored: _propTypes2.default.bool,
  empty: _propTypes2.default.bool,
  renderTableToDom: _propTypes2.default.bool
};

Table.propTypes = {
  className: _propTypes2.default.string,
  children: _propTypes2.default.node,
  bordered: _propTypes2.default.bool,
  fixedLayout: _propTypes2.default.bool,
  loading: _propTypes2.default.bool,
  errored: _propTypes2.default.bool,
  empty: _propTypes2.default.bool,
  noItemsNode: _propTypes2.default.node,
  noItemsMatchingSearchNode: _propTypes2.default.node,
  errorNode: _propTypes2.default.node,
  searching: _propTypes2.default.bool,
  translations: _propTypes2.default.object,
  renderTableToDom: _propTypes2.default.bool //if true to render a table HTML element, otherwise a div
};

Table.defaultProps = {
  bordered: true,
  fixedLayout: true,
  loading: false,
  empty: false,
  searching: false,
  renderTableToDom: true, //by default render a table HTML element
  translations: {
    noItems: 'There are currently no records.',
    noItemsMatchingSearchTerm: "Hmm... We couldn't find any matching records",
    error: 'Looks like something went wrong... Please try again later.',
    loading: 'Loading'
  }
};

exports.default = Table;