'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _cfStyleContainer = require('cf-style-container');

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const tableCellStyles = ({
  align,
  bordered,
  textEllipsis,
  theme,
  hover,
  width,
  hideOnMobile
}) => ({
  display: hideOnMobile ? 'none' : 'table-cell',
  lineHeight: '1.5',
  verticalAlign: 'middle',
  textAlign: align ? align : 'initial',
  width: width ? width : 'auto',
  whiteSpace: textEllipsis ? 'nowrap' : 'initial',
  overflow: textEllipsis ? 'hidden' : 'initial',
  borderLeft: bordered ? `1px solid ${theme.colors.gray[7]}` : 'none',
  paddingTop: theme.space[2],
  paddingBottom: theme.space[2],
  paddingLeft: theme.space[3],
  paddingRight: theme.space[3],
  mobileWide: {
    display: 'table-cell'
  },
  textOverflow: textEllipsis ? 'ellipsis' : 'initial',
  '&:last-child': {
    borderRight: bordered ? `1px solid ${theme.colors.gray[7]}` : 'none'
  },
  '&:hover': hover ? {
    backgroundColor: `${theme.colors.gray[6]}!important`,
    cursor: 'pointer'
  } : undefined
});

const TableHeadCell = (0, _cfStyleContainer.createComponent)(tableCellStyles, 'th', ['colSpan', 'onClick']);
TableHeadCell.setDisplayName('TableHeadCell');

const TableRowCell = (0, _cfStyleContainer.createComponent)(tableCellStyles, 'td', ['colSpan', 'onClick']);
TableRowCell.setDisplayName('TableRowCell');

class TableCell extends _react2.default.Component {
  render() {
    const {
      align,
      children,
      className,
      colSpan,
      hideOnMobile,
      hover,
      textEllipsis,
      width,
      onClick
    } = this.props;
    const { bordered, isHeader } = this.context;

    return isHeader ? _react2.default.createElement(
      TableHeadCell,
      {
        align: align,
        bordered: bordered,
        className: className,
        colSpan: colSpan,
        hideOnMobile: hideOnMobile,
        hover: hover,
        textEllipsis: textEllipsis,
        width: width,
        onClick: onClick
      },
      children
    ) : _react2.default.createElement(
      TableRowCell,
      {
        align: align,
        bordered: bordered,
        className: className,
        colSpan: colSpan,
        hideOnMobile: hideOnMobile,
        hover: hover,
        textEllipsis: textEllipsis,
        width: width,
        onClick: onClick
      },
      children
    );
  }
}

const CellPropTypes = {
  align: _propTypes2.default.oneOf(['left', 'center', 'right']),
  children: _propTypes2.default.node,
  className: _propTypes2.default.string,
  colSpan: _propTypes2.default.number,
  hideOnMobile: _propTypes2.default.bool,
  hover: _propTypes2.default.bool,
  textEllipsis: _propTypes2.default.bool,
  width: _propTypes2.default.string,
  onClick: _propTypes2.default.func
};

TableHeadCell.propTypes = CellPropTypes;
TableRowCell.propTypes = CellPropTypes;

TableCell.contextTypes = {
  bordered: _propTypes2.default.bool,
  isHeader: _propTypes2.default.bool
};

TableCell.propTypes = CellPropTypes;

TableCell.defaultProps = {
  align: 'left',
  textEllipsis: false,
  hideOnMobile: false,
  hover: false
};

exports.default = TableCell;